@@ -1,5 +1,5 @@
 package Elastic::Model;
-$Elastic::Model::VERSION = '0.51';
+$Elastic::Model::VERSION = '0.52';
 use Moose 2.06 ();
 use Moose::Exporter();
 use Carp;
@@ -98,7 +98,7 @@ Elastic::Model - A NoSQL document store with full text search for Moose objects
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 SYNOPSIS
 
@@ -137,6 +137,32 @@ It is designed to make it easy to start using Elasticsearch with minimal extra
 code, but allows you full access to the rich feature set available in
 Elasticsearch as soon as you are ready to use it.
 
+=head1 FUTURE OF ELASTIC::MODEL - PLEASE READ AND COMMENT
+
+Hi all users of Elastic::Model
+
+Elasticsearch 2.0.0 is out, and Elastic::Model doesn't support it.
+In fact, Elastic::Model doesn't support a number of things from
+Elasticsearch 1.x either. I apologise for neglecting this module.
+
+My feeling is that Elastic::Model tries to do way too much.
+Like many frameworks, it ties you into doing things in a
+particular way, which may or may not make sense for your use
+case. Most people who use Elastic::Model seem to use a
+subset of the functionality, and then talk to Elasticsearch
+directly the rest of the time.
+
+I don't think it makes sense to just update the code for
+2.x, it needs a complete rethink.
+
+=head2 TELL ME HOW YOU USE IT
+
+Please could you add comments to
+L<this issue|https://github.com/clintongormley/Elastic-Model/issues/42>
+explaining what bits you find useful, what bits you never use,
+and what bits you find annoying. Perhaps the code can be split
+out into smaller more useful chunks.
+
 =head1 INTRODUCTION TO Elastic::Model
 
 If you are not familiar with L<Elastic::Model>, you should start by reading
@@ -148,8 +174,9 @@ L<Elastic::Model> module itself.
 =head1 BACKWARDS COMPATIBILITY BREAK
 
 B<NOTE:> This version of Elastic::Model uses L<Search::Elasticsearch>
-and is intended for Elasticsearch 1.0 and above. However, it can be used
-with Elasticsearch 0.90.x in "compatibility mode".
+and is intended for Elasticsearch 1.x. However, it can be used
+with Elasticsearch 0.90.x in "compatibility mode". Elasticsearch 2.x is
+not supported.
 
 B<< You can no longer use the old L<Search::Elasticsearch::Compat>. >>
 See L<Elastic::Manual::Delta> for instructions.
