@@ -1,5 +1,5 @@
 package Elastic::Model::Role::Model;
-$Elastic::Model::Role::Model::VERSION = '0.51';
+$Elastic::Model::Role::Model::VERSION = '0.52';
 use Moose::Role;
 use Carp;
 use Elastic::Model::Types qw(ES);
@@ -155,7 +155,7 @@ has 'current_scope' => (
 
 #===================================
 sub _build_store { $_[0]->store_class->new( es => $_[0]->es ) }
-sub _build_es { Search::Elasticsearch->new }
+sub _build_es { Search::Elasticsearch->new( client => '1_0::Direct' ) }
 #===================================
 
 #===================================
@@ -661,13 +661,16 @@ Elastic::Model::Role::Model - The role applied to your Model
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 SYNOPSIS
 
     use MyApp;
 
-    my $es         = Search::Elasticsearch->new( nodes => 'es.domain.com:9200' );
+    my $es         = Search::Elasticsearch->new(
+        client => '1_0::Direct',
+        nodes  => 'es.domain.com:9200'
+    );
     my $model      = MyApp->new( es => $es );
 
     my $namespace  = $model->namespace('myapp');
