@@ -34,9 +34,9 @@ has 'multi_attr' => (
 #===================================
 has 'bad_opt_attr' => (
 #===================================
-    is         => 'ro',
-    isa        => 'Bool',
-    omit_norms => 1,
+    is       => 'ro',
+    isa      => 'Bool',
+    analyzer => 'standard',
 );
 
 #===================================
@@ -44,7 +44,7 @@ has 'bad_multi_attr' => (
 #===================================
     is    => 'ro',
     isa   => 'Bool',
-    multi => { one => { omit_term_freq_and_positions => 1 } }
+    multi => { one => { analyzer => 'standard' } }
 );
 
 1;
